@@ -130,9 +130,6 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_TABLE_EDITOR,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_TYPE_WINDOW,
-			       NULL, glade_standard_build_children,
-			       gnomedb_window_find_internal_child);
 
 	glade_provide ("gnomedb");
 }
