@@ -712,6 +712,7 @@ gnome_db_grid_set_title (GnomeDbGrid *grid, const gchar *title)
 		g_free (grid->priv->title_string);
 
 	grid->priv->title_string = g_strdup (title);
+
 	gnome_db_gray_bar_set_text (GNOME_DB_GRAY_BAR (grid->priv->title), title);
 }
 
@@ -735,7 +736,7 @@ gnome_db_grid_get_show_title (GnomeDbGrid *grid)
  * @grid: a #GnomeDbGrid widget.
  * @show: whether to show the title or not.
  *
- * Set the title displating mode for the given grid.
+ * Set the title displaying mode for the given grid.
  */
 void
 gnome_db_grid_set_show_title (GnomeDbGrid *grid, gboolean show)
@@ -749,6 +750,73 @@ gnome_db_grid_set_show_title (GnomeDbGrid *grid, gboolean show)
 		gtk_widget_hide (grid->priv->title);
 }
 
+/**
+ * gnome_db_grid_set_title_icon_from_file
+ * @grid: a #GnomeDbGrid widget.
+ * @file: image filename.
+ *
+ * Set the icon for the given grid.
+ */
+void
+gnome_db_grid_set_title_icon_from_file (GnomeDbGrid *grid, const gchar *file)
+{
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	gnome_db_gray_bar_set_icon_from_file (GNOME_DB_GRAY_BAR (grid->priv->title),
+					      file);
+}
+
+/**
+ * gnome_db_grid_set_title_icon_from_stock
+ * @grid: a #GnomeDbGrid widget.
+ * @stock_id: a stock icon name.
+ * @size: a stock icon size.
+ *
+ * Set the icon using a stock icon for the given grid.
+ */
+void
+gnome_db_grid_set_title_icon_from_stock (GnomeDbGrid *grid,
+					 const gchar *stock_id,
+					 GtkIconSize  size)
+{
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+	
+	gnome_db_gray_bar_set_icon_from_stock (GNOME_DB_GRAY_BAR (grid->priv->title),
+					       stock_id, size);
+}
+
+/**
+ * gnome_db_grid_set_show_title_icon
+ * @grid: a #GnomeDbGrid widget.
+ * @show: whether to show the icon or not.
+ *
+ * Set the icon displaying mode for the given grid.
+ */
+void
+gnome_db_grid_set_show_title_icon (GnomeDbGrid *grid, gboolean show)
+{
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+	
+	gnome_db_gray_bar_set_show_icon (GNOME_DB_GRAY_BAR (grid->priv->title),
+					 show);
+}
+
+/**
+ * gnome_db_grid_get_show_title_icon
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Get whether the icon is being shown for the given grid.
+ *
+ * Returns: TRUE if the icon is shown, FALSE if not.
+ */
+gboolean
+gnome_db_grid_get_show_title_icon (GnomeDbGrid *grid)
+{
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), FALSE);
+	
+	return gnome_db_gray_bar_get_show_icon (GNOME_DB_GRAY_BAR (grid->priv->title));
+}
+
 /**
  * gnome_db_grid_get_model
  */
